@@ -2,10 +2,11 @@ import platform
 import sys
 from itertools import chain
 
-from paradigm import modules
 from .utils import (_add,
+                    _add_module,
                     _to_callables,
-                    _update)
+                    _update,
+                    _update_modules)
 
 # importing will cause unwanted side effects such as raising error
 stdlib_modules_names = {'antigravity', 'crypt', 'this'}
@@ -24,28 +25,27 @@ stdlib_modules = set()
 
 if platform.python_implementation() != 'PyPy':
     # not supported by ``typeshed`` package
-    stdlib_modules.update(map(modules.safe_import,
-                              ['_collections',
-                               '_codecs_hk',
-                               '_codecs_iso2022',
-                               '_codecs_jp',
-                               '_codecs_kr',
-                               '_codecs_cn',
-                               '_codecs_tw',
-                               '_lsprof',
-                               '_multibytecodec',
-                               '_multiprocessing',
-                               '_string',
-                               'audioop',
-                               'parser',
-                               'xxsubtype']))
+    _update_modules(stdlib_modules, ['_collections',
+                                     '_codecs_hk',
+                                     '_codecs_iso2022',
+                                     '_codecs_jp',
+                                     '_codecs_kr',
+                                     '_codecs_cn',
+                                     '_codecs_tw',
+                                     '_lsprof',
+                                     '_multibytecodec',
+                                     '_multiprocessing',
+                                     '_string',
+                                     'audioop',
+                                     'parser',
+                                     'xxsubtype'])
 
     if sys.version_info >= (3, 6):
-        stdlib_modules.add(modules.safe_import('_sha3'))
+        _add_module(stdlib_modules, '_sha3')
 
     if ((3, 6) <= sys.version_info < (3, 6, 7)
             or (3, 7) <= sys.version_info < (3, 7, 1)):
-        stdlib_modules.add(modules.safe_import('_blake2'))
+        _add_module(stdlib_modules, '_blake2')
 
 stdlib_modules_callables = list(chain.from_iterable(map(_to_callables,
                                                         stdlib_modules)))
@@ -94,7 +94,14 @@ if platform.python_implementation() != 'PyPy':
                                                            'channel_list_all',
                                                            'run_string'])
 
-    if sys.platform != 'win32':
+    if sys.version_info >= (3, 9):
+        _add(built_in_functions, '_xxsubinterpreters',
+             'channel_list_interpreters')
+
+    if sys.platform == 'win32':
+        if sys.version_info >= (3, 7):
+            _add(built_in_functions, '_uuid', 'UuidCreate')
+    else:
         _update(built_in_functions, '_locale', ['bind_textdomain_codeset',
                                                 'bindtextdomain',
                                                 'dcgettext',
@@ -103,6 +110,7 @@ if platform.python_implementation() != 'PyPy':
                                                 'textdomain'])
 
         if sys.version_info >= (3, 7):
+            _add(built_in_functions, '_uuid', 'generate_time_safe')
             _add(built_in_functions, 'time', 'pthread_getcpuclockid')
         if sys.version_info >= (3, 8):
             _update(built_in_functions, 'posix', ['posix_spawn',
